@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -61,6 +61,8 @@ public:
         }
         return package.move();
     };
+    void configure(const xmlNode * ptr, bool test_only,
+                   const char *path) { };
 };
 
 int main(int argc, char **argv)
